@@ -2,11 +2,11 @@ from fastutil import gpu_util, loguru_util, logging_util, message_util, task_uti
 from loguru import logger
 from fastutil import cleaner
 import argparse
-import importlib
+from git import Repo
 
 
 def test_util():
-    message_util.send_email('测试日志', '收到了吗','464840061@qq.com')
+    message_util.send_email('测试日志', '收到了吗', '464840061@qq.com')
     logging_util.set_rotating_logger(__name__, 'log/test.log')
     loguru_util.add_path('log/test1.log')
     loguru_util.add_email('错误日志', '464840061@qq.com')
@@ -29,7 +29,7 @@ def test_clean():
     print(list(_cleaner.clean_sentences(docs)))
 
 
-@model_util.log_record(config_module=logging_util, data_dir='log/' + model_util.get_ver_id())
+@model_util.log_record(config_module=logging_util, save_dir='log/' + model_util.get_ver_id(), check_commit=True)
 @logger.catch()
 def test_task(a):
     parser = argparse.ArgumentParser(description='使用示例：taskkill train.py')
